CompanionDeviceManagerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- CompanionDeviceManagerPlatform
- Implementers
Constructors
- CompanionDeviceManagerPlatform()
- Constructs a CompanionDeviceManagerPlatform.
Properties
-
backgroundEvents
→ Stream<
CompanionDeviceEvent> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associate(
CompanionDeviceAssociationRequest request) → Future< CompanionDeviceAssociation> -
associateByMacAddress(
String macAddress) → Future< CompanionDeviceAssociation> -
clearBackgroundCallback(
) → Future< void> -
clearNativeDebugLog(
) → Future< void> -
disassociate(
CompanionDeviceAssociation association) → Future< void> -
disassociateByMacAddress(
String macAddress) → Future< void> -
getAssociations(
) → Future< List< CompanionDeviceAssociation> > -
getLastBackgroundEvent(
) → Future< CompanionDeviceEvent?> -
getNativeDebugLog(
) → Future< String?> -
isAvailable(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerBackgroundCallback(
CompanionDeviceBackgroundCallback callback) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ CompanionDeviceManagerPlatform
-
The default instance of CompanionDeviceManagerPlatform to use.
getter/setter pair