MethodChannelCompanionDeviceManager class
An implementation of CompanionDeviceManagerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- CompanionDeviceManagerPlatform
- MethodChannelCompanionDeviceManager
Constructors
Properties
-
backgroundEvents
→ Stream<
CompanionDeviceEvent> -
no setteroverride
- eventChannel → EventChannel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
associate(
CompanionDeviceAssociationRequest request) → Future< CompanionDeviceAssociation> -
override
-
associateByMacAddress(
String macAddress) → Future< CompanionDeviceAssociation> -
inherited
-
clearBackgroundCallback(
) → Future< void> -
override
-
clearNativeDebugLog(
) → Future< void> -
override
-
disassociate(
CompanionDeviceAssociation association) → Future< void> -
override
-
disassociateByMacAddress(
String macAddress) → Future< void> -
inherited
-
getAssociations(
) → Future< List< CompanionDeviceAssociation> > -
override
-
getLastBackgroundEvent(
) → Future< CompanionDeviceEvent?> -
override
-
getNativeDebugLog(
) → Future< String?> -
override
-
isAvailable(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerBackgroundCallback(
CompanionDeviceBackgroundCallback callback) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited